ImageConverter

Struct ImageConverter 

pub struct ImageConverter { /* private fields */ }
Safe wrapper for working with the wkhtmltoimage converter

Implementations

Source

impl ImageConverter

pub fn convert<'a>(self) -> Result<ImageOutput<'a>>

Performs the HTML to image conversion

This method does not do any additional allocations of the output, so the ImageConverter will be owned by ImageOutput so that it is not dropped until the ImageOutput is dropped.